@@ -340,6 +340,18 @@ class MiddlewareTestCase(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, "<h1>Demo CSS</h1>")
 
+    @patch('adminlte2_pdq.middleware.LOGIN_REQUIRED', True)
+    @patch('adminlte2_pdq.middleware.STRICT_POLICY', True)
+    @patch('adminlte2_pdq.middleware.WEBSOCKET_ROUTE', '/demo-css/')  # Pretend the demo-css route is a websocket file.
+    def test_middleware_allows_when_websocket_url_defined_login_on_strict_on_login_wl_on_strict_wl_on(self):
+        """test_middleware_allows_when_websocket_url_defined_login_on_strict_on_login_wl_on_strict_wl_on"""
+        response = self.client.get(
+            reverse('adminlte2_pdq:demo-css'),
+            follow=True
+        )
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, "<h1>Demo CSS</h1>")
+
     # **************************************************************************
     # Logged In User - All Perms - Staff Status - Can see Admin page.
     # **************************************************************************
